@@ -232,8 +232,8 @@ applydelta(FILE *fpold, struct cfile *ocf, struct cfile *cf, unsigned char *outd
   newl = cget4(cf);
   inn = cget4(cf);
   outn = cget4(cf);
-  in = xmalloc(2 * inn * sizeof(unsigned int));
-  out = xmalloc(2 * outn * sizeof(unsigned int));
+  in = xmalloc2(inn, 2 * sizeof(unsigned int));
+  out = xmalloc2(outn, 2 * sizeof(unsigned int));
   for (i = 0; i < inn; i++)
     in[2 * i] = cget4(cf);
   for (i = 0; i < inn; i++)
@@ -406,7 +406,7 @@ int main(int argc, char **argv)
   /* switch to compression */
   cf = cfile_open(CFILE_OPEN_RD, CFILE_IO_FILE, fpdlt, CFILE_COMP_BZ, CFILE_LEN_UNLIMITED, 0, 0);
   nmpn = cget4(cf);
-  nmp = xmalloc((nmpn * 2 + 2) * sizeof(*nmp));
+  nmp = xmalloc2(nmpn + 1, 2 * sizeof(*nmp));
   for (i = 0; i < nmpn * 2 + 1; i++)
     nmp[i] = cget4(cf);
   nmp[i] = 0;
