@@ -338,27 +338,18 @@ fillblock_prelink(struct blk *b, int id, struct seqdescr *sd, struct fileblock *
 
   /* go to first block that doesn't start in the middle of a
    * prelinked file */
+  off = id << BLKSHIFT;
   for (;;)
     {
-      off = id << BLKSHIFT;
       while (sd->off > off)
-	{
-	  if (fd != -1)
-	    {
-	      if (isp)
-	        prelinked_close(fd);
-	      else
-	        close(fd);
-	      fd = -1;
-	    }
-	  sd--;
-	}
+        sd--;
       /* now sd contains off */
-      if (sd->off + sd->cpiolen >= off)
+      if (sd->i == -1 || sd->datalen == 0 || sd->off + sd->cpiolen >= off)
 	break;
-      /* off in file, check if prelinked */
+      if (S_ISLNK(fb->filemodes[sd->i]))
+	break;
+      /* off in regular file, check if prelinked */
       name = fb->filenames[sd->i];
-      isp = 0;
       if ((fd = open(name, O_RDONLY)) == -1)
 	{
 	  perror(name);
@@ -369,12 +360,32 @@ fillblock_prelink(struct blk *b, int id, struct seqdescr *sd, struct fileblock *
 	break;
       if (!is_prelinked(fd, buf, pread(fd, buf, 128, (off_t)0)))
 	break;
-      isp = 1;
-      id--;
+      close(fd);
+      fd = -1;
+      /* rewind blocks until we leave the file */
+      do
+	{
+	  id--;
+	  off = id << BLKSHIFT;
+	}
+      while (sd->off + sd->cpiolen < off);
     }
   /* ok, got id, sd and maybe fd. create blocks. */
   l = BLKSIZE;
   bp = b->e.buf;
+  if (fd != -1)
+    {
+      unsigned int u = off - (sd->off + sd->cpiolen);
+      if (u && u < fb->filesizes[sd->i])
+	{
+	  if (lseek(fd, (off_t)u, SEEK_SET) == (off_t)-1)
+	    {
+	      fprintf(stderr, "%s: seek error\n", fb->filenames[sd->i]);
+	      fprintf(stderr, "cannot reconstruct rpm from disk files\n");
+	      exit(1);
+	    }
+	}
+    }
   for (;;)
     {
       while (l)
@@ -424,6 +435,7 @@ fillblock_prelink(struct blk *b, int id, struct seqdescr *sd, struct fileblock *
 	      bp += l2;
 	      off += l2;
 	      l -= l2;
+	      o += l2;
 	      l2 = l > sd->datalen - o ? sd->datalen - o : l;
 	      if (l2 > 0)
 		{
@@ -590,6 +602,7 @@ fillblock_disk(struct blk *b, int id, struct seqdescr *sdesc, int nsdesc, struct
 	      if (!of)
 		{
 		  fillblock_prelink(b, id, sd, fb, idx);
+		  csdesc = -1;
 		  return;
 		}
 	      if (of->next)
@@ -1667,10 +1680,8 @@ main(int argc, char **argv)
 		  if (percent > 1)
 		    fprintf(vfp, "%d percent finished.\n", curpercent);
 		  else
-		    {
-		      fprintf(vfp, "\r%d percent finished.", curpercent);
-		      fflush(vfp);
-		    }
+		    fprintf(vfp, "\r%d percent finished.", curpercent);
+		  fflush(vfp);
 		  lastpercent = curpercent;
 		}
 	    }
