@@ -605,7 +605,14 @@ cwopen_gz(struct cfile *f)
 
   f->crc = crc32(0L, Z_NULL, 0);
   f->crclen = 0;
+#ifdef Z_RSYNCABLE
   ret = deflateInit2(&f->strm.gz, Z_BEST_COMPRESSION, Z_DEFLATED, -MAX_WBITS, 8, Z_DEFAULT_STRATEGY | (f->comp == CFILE_COMP_GZ_RSYNC ? Z_RSYNCABLE : 0));
+#else
+  if (f->comp == CFILE_COMP_GZ_RSYNC)
+    ret = Z_VERSION_ERROR;
+  else
+    ret = deflateInit2(&f->strm.gz, Z_BEST_COMPRESSION, Z_DEFLATED, -MAX_WBITS, 8, Z_DEFAULT_STRATEGY);
+#endif
   if (ret != Z_OK)
     {
       free(f);
@@ -705,6 +712,8 @@ crunread_un(struct cfile *f, void *buf, int len)
 }
 
 
+#ifdef Z_RSYNCABLE
+
 int
 cfile_detect_rsync(struct cfile *f)
 {
@@ -868,6 +877,16 @@ cfile_detect_rsync(struct cfile *f)
   return comp == -1 ? -1 : 0;
 }
 
+#else
+
+int
+cfile_detect_rsync(struct cfile *f)
+{
+  return -1;
+}
+
+#endif
+
 /*****************************************************************
  *  our open function
  */
