@@ -437,7 +437,7 @@ gotit:
       if (len == oldscore)
 	scan += len;
       else
-	scan++;
+	scan = lscan + 1;
       scanstart = scan;
       if (scan + HSIZE < newlen)
 	ssx = buzhash(new + scan);
