@@ -9,6 +9,7 @@
 #define TAG_VERSION     1001
 #define TAG_RELEASE     1002
 #define TAG_EPOCH       1003
+#define TAG_ARCH        1022
 #define TAG_FILENAMES   1027
 #define TAG_FILESIZES   1028
 #define TAG_FILEMODES   1030
@@ -19,12 +20,20 @@
 #define TAG_FILEFLAGS   1037
 #define TAG_SOURCERPM   1044
 #define TAG_FILEVERIFY  1045
+#define TAG_NOSOURCE    1051
+#define TAG_NOPATCH     1052
 #define TAG_DIRINDEXES  1116
 #define TAG_BASENAMES   1117
 #define TAG_DIRNAMES    1118
 #define TAG_PAYLOADFORMAT 1124
 #define TAG_PAYLOADCOMPRESSOR 1125
 
+#define SIGTAG_SIZE     1000
+#define SIGTAG_MD5      1004
+#define SIGTAG_GPG      1005
+#define SIGTAG_PAYLOADSIZE 1007
+#define SIGTAG_SHA1     269
+
 #define FILE_CONFIG     (1 << 0)
 #define FILE_MISSINGOK  (1 << 3)
 #define FILE_GHOST      (1 << 6)
@@ -54,3 +63,4 @@ unsigned char *headbin(struct rpmhead *h, int tag, int len);
 char **headstringarray(struct rpmhead *h, int tag, int *cnt);
 char **headexpandfilelist(struct rpmhead *h, int *cnt);
 char *headtonevr(struct rpmhead *h);
+int headtagtype(struct rpmhead *h, int tag);
